RepNCAplot<-function(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis){
  NCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis,
                  replicated=TRUE, parallel=FALSE)
  }